@@ -115,7 +115,8 @@ static void _mf_callback_expect_pattern(char* line) {
 
 static int _detect_features_from_make(struct _makefile_features* mf) {
   SRCINST_SPAWN_ID id; 
-  int i, log;
+  int i, log_out, log_err;
+  struct _callback_node* call_out;
 
   if (!(id = srcinst_spawn(PRG_make, "-f", mf->makefile, "-q", "-p", 0))) {
     return 0;
@@ -125,18 +126,34 @@ static int _detect_features_from_make(struct _makefile_features* mf) {
     _mf_preg[i] = srcinst_init_regex(mf->features[i].pattern, -1);
   }
 
-  if ((log = _srcinst_state.log_stdout)) {
+  if ((log_out = _srcinst_state.log_stdout)) {
     _srcinst_state.log_stdout = 0;
   }
 
+  if ((call_out = _srcinst_state.stdout_callbacks.first)) {
+    _srcinst_state.stdout_callbacks.first = 0;
+  }
+
+  if ((log_err = _srcinst_state.log_stderr)) {
+    _srcinst_state.log_stderr = 0;
+  }
+
   srcinst_register_stdout_callback(&_mf_callback_expect_pattern);
   (void)srcinst_wait(id);
   srcinst_unregister_stdout_callback(&_mf_callback_expect_pattern);
-
-  if (log) {
+  
+  if (log_out) {
     _srcinst_state.log_stdout = 1;
   }
   
+  if (log_err) {
+    _srcinst_state.log_stderr = 1;
+  }
+
+  if (call_out) {
+    _srcinst_state.stdout_callbacks.first = call_out;
+  }
+  
   for (i = 0; i < SRCINST_FEATURE_N; i++) {
     if (!_mf_preg[i]) {
       mf->features[i].supported = 1;
