@@ -34,14 +34,16 @@
 #define SRCINST_ONCLOSE_ADD 0x02    /* on close, add this package */
 
 struct _package_info {
-  char loaded;
+
+  char loaded;			/* whether the package is loaded */
+  struct _package_element* upgrading_from; /* if not null, the package we are upgrading from */
 
   /* build time information */
   unsigned char onclose;
   char build_ready;
   char* packdir;		 /* package initialized build directory */
 
-  /* package info proper */
+  /* package info proper (serialized) */
   char* name;
 
   char* description;
